"""
    Global Filings API

    The Filings API provides a comprehensive set of functionalities for searching and retrieving filing documents from various sources.  This API is designed to expose document search and document retrieval functionality. A document search will allow a request to query FactSet’s document databases based on certain search criteria specified in the request.  In addition, a document count request will provide information on the number of stories available for a particular security.  Helper endpoint will provide dynamic information on the parameters of a document request. .  # noqa: E501

    The version of the OpenAPI document: 0.0.0
    Contact: api@factset.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401
from multiprocessing.pool import ApplyResult
import typing

from fds.sdk.GlobalFilings.api_client import ApiClient, Endpoint as _Endpoint
from fds.sdk.GlobalFilings.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from fds.sdk.GlobalFilings.exceptions import ApiException
from fds.sdk.GlobalFilings.model.error_response import ErrorResponse
from fds.sdk.GlobalFilings.model.investment_research import InvestmentResearch
from fds.sdk.GlobalFilings.model.response_count import ResponseCount
from fds.sdk.GlobalFilings.model.response_helper import ResponseHelper





class FilingsAPIApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

        self.get_count_endpoint = _Endpoint(
            settings={
                'response_type': (
                  { 200: (ResponseCount,), 400: (ErrorResponse,), 401: (ErrorResponse,), 403: (ErrorResponse,), 500: (ErrorResponse,),  },
                  None
                ),
                'auth': [
                    'FactSetApiKey',
                    'FactSetOAuth2'
                ],
                'endpoint_path': '/count',
                'operation_id': 'get_count',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'report',
                    'sources',
                    'start_date',
                    'end_date',
                    'ids',
                ],
                'required': [
                    'report',
                    'sources',
                ],
                'nullable': [
                ],
                'enum': [
                    'report',
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                    ('report',): {

                        "COUNT": "count"
                    },
                },
                'openapi_types': {
                    'report':
                        (str,),
                    'sources':
                        ([str],),
                    'start_date':
                        (str,),
                    'end_date':
                        (str,),
                    'ids':
                        ([str],),
                },
                'attribute_map': {
                    'report': 'report',
                    'sources': 'sources',
                    'start_date': 'startDate',
                    'end_date': 'endDate',
                    'ids': 'ids',
                },
                'location_map': {
                    'report': 'query',
                    'sources': 'query',
                    'start_date': 'query',
                    'end_date': 'query',
                    'ids': 'query',
                },
                'collection_format_map': {
                    'sources': 'csv',
                    'ids': 'csv',
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )

        self.get_filings_endpoint = _Endpoint(
            settings={
                'response_type': (
                  { 200: (InvestmentResearch,), 400: (ErrorResponse,), 401: (ErrorResponse,), 403: (ErrorResponse,), 500: (ErrorResponse,),  },
                  None
                ),
                'auth': [
                    'FactSetApiKey',
                    'FactSetOAuth2'
                ],
                'endpoint_path': '/search',
                'operation_id': 'get_filings',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'sources',
                    'ids',
                    'start_date',
                    'end_date',
                    'pagination_limit',
                    'pagination_offset',
                    'timezone',
                    'sort',
                    'categories',
                    'primary_id',
                    'search_text',
                    'form_type',
                    'accession',
                ],
                'required': [
                    'sources',
                ],
                'nullable': [
                ],
                'enum': [
                    'sort',
                    'primary_id',
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                    ('sort',): {

                        "ASC": "asc",
                        "DESC": "desc"
                    },
                    ('primary_id',): {

                        "Y": "Y",
                        "N": "N"
                    },
                },
                'openapi_types': {
                    'sources':
                        ([str],),
                    'ids':
                        ([str],),
                    'start_date':
                        (str,),
                    'end_date':
                        (str,),
                    'pagination_limit':
                        (int,),
                    'pagination_offset':
                        (int,),
                    'timezone':
                        (str,),
                    'sort':
                        (str,),
                    'categories':
                        ([str],),
                    'primary_id':
                        (str,),
                    'search_text':
                        (str,),
                    'form_type':
                        (str,),
                    'accession':
                        (str,),
                },
                'attribute_map': {
                    'sources': 'sources',
                    'ids': 'ids',
                    'start_date': 'startDate',
                    'end_date': 'endDate',
                    'pagination_limit': 'paginationLimit',
                    'pagination_offset': 'paginationOffset',
                    'timezone': 'timezone',
                    'sort': 'sort',
                    'categories': 'categories',
                    'primary_id': 'primaryId',
                    'search_text': 'searchText',
                    'form_type': 'formType',
                    'accession': 'accession',
                },
                'location_map': {
                    'sources': 'query',
                    'ids': 'query',
                    'start_date': 'query',
                    'end_date': 'query',
                    'pagination_limit': 'query',
                    'pagination_offset': 'query',
                    'timezone': 'query',
                    'sort': 'query',
                    'categories': 'query',
                    'primary_id': 'query',
                    'search_text': 'query',
                    'form_type': 'query',
                    'accession': 'query',
                },
                'collection_format_map': {
                    'sources': 'csv',
                    'ids': 'csv',
                    'categories': 'csv',
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )

        self.get_helper_endpoint = _Endpoint(
            settings={
                'response_type': (
                  { 200: (ResponseHelper,), 400: (ErrorResponse,), 401: (ErrorResponse,), 403: (ErrorResponse,), 500: (ErrorResponse,),  },
                  None
                ),
                'auth': [
                    'FactSetApiKey',
                    'FactSetOAuth2'
                ],
                'endpoint_path': '/helper',
                'operation_id': 'get_helper',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'fields',
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                    'fields',
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                    ('fields',): {

                        "SOURCES": "sources",
                        "FORMTYPES": "formTypes",
                        "TIMEZONES": "timeZones",
                        "CATEGORIES": "categories"
                    },
                },
                'openapi_types': {
                    'fields':
                        (str,),
                },
                'attribute_map': {
                    'fields': 'fields',
                },
                'location_map': {
                    'fields': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )


    @staticmethod
    def apply_kwargs_defaults(kwargs, return_http_data_only, async_req):
        kwargs["async_req"] = async_req
        kwargs["_return_http_data_only"] = return_http_data_only
        kwargs["_preload_content"] = kwargs.get("_preload_content", True)
        kwargs["_request_timeout"] = kwargs.get("_request_timeout", None)
        kwargs["_check_input_type"] = kwargs.get("_check_input_type", True)
        kwargs["_check_return_type"] = kwargs.get("_check_return_type", True)
        kwargs["_spec_property_naming"] = kwargs.get("_spec_property_naming", False)
        kwargs["_content_type"] = kwargs.get("_content_type")
        kwargs["_host_index"] = kwargs.get("_host_index")


    def get_count(
        self,
        sources,
        report="count",
        **kwargs
    ) -> ResponseCount:
        """Returns the count of filings for specified source  # noqa: E501

        Returns the count of filings documents along with other response fields.  # noqa: E501
        This method makes a synchronous HTTP request. Returns the http data only

        Args:
            sources ([str]): Code for document source to include.This is a comma-separated list. Use the ```/helper``` endpoint to get the list of available sources.  
            report (str): retrives count of source.. defaults to "count", must be one of ["count"]

        Keyword Args:
            start_date (str): Start Date. Format is YYYYMMDD or relative +/- days (0,-1,etc).. [optional] if omitted the server will use the default value of "0"
            end_date (str): End Date. Format is YYYYMMDD or relative +/- days (0,-1,etc).. [optional] if omitted the server will use the default value of "0"
            ids ([str]): Requested symbols or securities.  This is a comma-separated list with a maximum limit of 1000.  Each symbol can be a FactSet exchange symbol, CUSIP, or SEDOL.. [optional]
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True. NOTE: if this API returns a file, it is the responsibility
                of the caller to close the file stream.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
        Returns:
            ResponseCount
                Response Object
        """
        self.apply_kwargs_defaults(kwargs=kwargs, return_http_data_only=True, async_req=False)
        kwargs['report'] = \
            report
        kwargs['sources'] = \
            sources
        return self.get_count_endpoint.call_with_http_info(**kwargs)

    def get_count_with_http_info(
        self,
        sources,
        report="count",
        **kwargs
    ) -> typing.Tuple[ResponseCount, int, typing.MutableMapping]:
        """Returns the count of filings for specified source  # noqa: E501

        Returns the count of filings documents along with other response fields.  # noqa: E501
        This method makes a synchronous HTTP request. Returns http data, http status and headers

        Args:
            sources ([str]): Code for document source to include.This is a comma-separated list. Use the ```/helper``` endpoint to get the list of available sources.  
            report (str): retrives count of source.. defaults to "count", must be one of ["count"]

        Keyword Args:
            start_date (str): Start Date. Format is YYYYMMDD or relative +/- days (0,-1,etc).. [optional] if omitted the server will use the default value of "0"
            end_date (str): End Date. Format is YYYYMMDD or relative +/- days (0,-1,etc).. [optional] if omitted the server will use the default value of "0"
            ids ([str]): Requested symbols or securities.  This is a comma-separated list with a maximum limit of 1000.  Each symbol can be a FactSet exchange symbol, CUSIP, or SEDOL.. [optional]
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True. NOTE: if this API returns a file, it is the responsibility
                of the caller to close the file stream.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
        Returns:
            ResponseCount
                Response Object
            int
                Http Status Code
            dict
                Dictionary of the response headers
        """
        self.apply_kwargs_defaults(kwargs=kwargs, return_http_data_only=False, async_req=False)
        kwargs['report'] = \
            report
        kwargs['sources'] = \
            sources
        return self.get_count_endpoint.call_with_http_info(**kwargs)

    def get_count_async(
        self,
        sources,
        report="count",
        **kwargs
    ) -> "ApplyResult[ResponseCount]":
        """Returns the count of filings for specified source  # noqa: E501

        Returns the count of filings documents along with other response fields.  # noqa: E501
        This method makes a asynchronous HTTP request. Returns the http data, wrapped in ApplyResult

        Args:
            sources ([str]): Code for document source to include.This is a comma-separated list. Use the ```/helper``` endpoint to get the list of available sources.  
            report (str): retrives count of source.. defaults to "count", must be one of ["count"]

        Keyword Args:
            start_date (str): Start Date. Format is YYYYMMDD or relative +/- days (0,-1,etc).. [optional] if omitted the server will use the default value of "0"
            end_date (str): End Date. Format is YYYYMMDD or relative +/- days (0,-1,etc).. [optional] if omitted the server will use the default value of "0"
            ids ([str]): Requested symbols or securities.  This is a comma-separated list with a maximum limit of 1000.  Each symbol can be a FactSet exchange symbol, CUSIP, or SEDOL.. [optional]
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True. NOTE: if this API returns a file, it is the responsibility
                of the caller to close the file stream.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
        Returns:
            ApplyResult[ResponseCount]
        """
        self.apply_kwargs_defaults(kwargs=kwargs, return_http_data_only=True, async_req=True)
        kwargs['report'] = \
            report
        kwargs['sources'] = \
            sources
        return self.get_count_endpoint.call_with_http_info(**kwargs)

    def get_count_with_http_info_async(
        self,
        sources,
        report="count",
        **kwargs
    ) -> "ApplyResult[typing.Tuple[ResponseCount, int, typing.MutableMapping]]":
        """Returns the count of filings for specified source  # noqa: E501

        Returns the count of filings documents along with other response fields.  # noqa: E501
        This method makes a asynchronous HTTP request. Returns http data, http status and headers, wrapped in ApplyResult

        Args:
            sources ([str]): Code for document source to include.This is a comma-separated list. Use the ```/helper``` endpoint to get the list of available sources.  
            report (str): retrives count of source.. defaults to "count", must be one of ["count"]

        Keyword Args:
            start_date (str): Start Date. Format is YYYYMMDD or relative +/- days (0,-1,etc).. [optional] if omitted the server will use the default value of "0"
            end_date (str): End Date. Format is YYYYMMDD or relative +/- days (0,-1,etc).. [optional] if omitted the server will use the default value of "0"
            ids ([str]): Requested symbols or securities.  This is a comma-separated list with a maximum limit of 1000.  Each symbol can be a FactSet exchange symbol, CUSIP, or SEDOL.. [optional]
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True. NOTE: if this API returns a file, it is the responsibility
                of the caller to close the file stream.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
        Returns:
            ApplyResult[(ResponseCount, int, typing.Dict)]
        """
        self.apply_kwargs_defaults(kwargs=kwargs, return_http_data_only=False, async_req=True)
        kwargs['report'] = \
            report
        kwargs['sources'] = \
            sources
        return self.get_count_endpoint.call_with_http_info(**kwargs)


    def get_filings(
        self,
        sources,
        **kwargs
    ) -> InvestmentResearch:
        """Returns the filings documents and related metadata within FactSet coverage.  # noqa: E501

        Returns the filings documents within FactSet coverage along with other response fields  # noqa: E501
        This method makes a synchronous HTTP request. Returns the http data only

        Args:
            sources ([str]): Code for document source to include.  This is a comma-separated list. Use the ```/helper``` endpoint to get the list of available sources.

        Keyword Args:
            ids ([str]): Requested symbols or securities.  This is a comma-separated list with a maximum limit of 1000.  Each symbol can be a FactSet exchange symbol, CUSIP, or SEDOL.. [optional]
            start_date (str): Start Date. Format is YYYYMMDD or relative +/- days (0,-1,etc).. [optional] if omitted the server will use the default value of "0"
            end_date (str): End Date. Format is YYYYMMDD or relative +/- days (0,-1,etc).. [optional] if omitted the server will use the default value of "0"
            pagination_limit (int): Number of results to return per page.. [optional] if omitted the server will use the default value of 25
            pagination_offset (int): Page number of the results to return.. [optional]
            timezone (str): Time zone to return story dates and times. Time zones are in POSIX format and automatically adjusted for daylight savings.. [optional] if omitted the server will use the default value of "America/New_York"
            sort (str): Sorting the results in chronological (oldest to newest) or reverse chronological (newest to oldest) order.    *  desc - sorting results in reverse chronological (descending) order. This is the default value if     the sort parameter isn’t used in the query       *   asc - sorting results in chronological (ascending) order. If a start date is not specified, the    API has a 10-year searching limitation. . [optional] if omitted the server will use the default value of "desc"
            categories ([str]): Code for categories to include.  This is a comma-separated list. Use the ```/helper``` endpoint to get the list of available categories.  Default = All categories.. [optional]
            primary_id (str): Type of identifier search * Y - Returns headlines of stories that have the search ID(s) as the Primary ID. * N - Returns headlines of stories that mention/refer to the ID(s).. [optional] if omitted the server will use the default value of "N"
            search_text (str): Restricts the search to include only document stories which include the text searched.. [optional]
            form_type (str): Restricts the search to include any form types of EDGAR.. [optional]
            accession (str): A unique identifier given to each EDGAR filings document. e.g. accession=0001013237-21-000069&sources=EDG. [optional]
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True. NOTE: if this API returns a file, it is the responsibility
                of the caller to close the file stream.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
        Returns:
            InvestmentResearch
                Response Object
        """
        self.apply_kwargs_defaults(kwargs=kwargs, return_http_data_only=True, async_req=False)
        kwargs['sources'] = \
            sources
        return self.get_filings_endpoint.call_with_http_info(**kwargs)

    def get_filings_with_http_info(
        self,
        sources,
        **kwargs
    ) -> typing.Tuple[InvestmentResearch, int, typing.MutableMapping]:
        """Returns the filings documents and related metadata within FactSet coverage.  # noqa: E501

        Returns the filings documents within FactSet coverage along with other response fields  # noqa: E501
        This method makes a synchronous HTTP request. Returns http data, http status and headers

        Args:
            sources ([str]): Code for document source to include.  This is a comma-separated list. Use the ```/helper``` endpoint to get the list of available sources.

        Keyword Args:
            ids ([str]): Requested symbols or securities.  This is a comma-separated list with a maximum limit of 1000.  Each symbol can be a FactSet exchange symbol, CUSIP, or SEDOL.. [optional]
            start_date (str): Start Date. Format is YYYYMMDD or relative +/- days (0,-1,etc).. [optional] if omitted the server will use the default value of "0"
            end_date (str): End Date. Format is YYYYMMDD or relative +/- days (0,-1,etc).. [optional] if omitted the server will use the default value of "0"
            pagination_limit (int): Number of results to return per page.. [optional] if omitted the server will use the default value of 25
            pagination_offset (int): Page number of the results to return.. [optional]
            timezone (str): Time zone to return story dates and times. Time zones are in POSIX format and automatically adjusted for daylight savings.. [optional] if omitted the server will use the default value of "America/New_York"
            sort (str): Sorting the results in chronological (oldest to newest) or reverse chronological (newest to oldest) order.    *  desc - sorting results in reverse chronological (descending) order. This is the default value if     the sort parameter isn’t used in the query       *   asc - sorting results in chronological (ascending) order. If a start date is not specified, the    API has a 10-year searching limitation. . [optional] if omitted the server will use the default value of "desc"
            categories ([str]): Code for categories to include.  This is a comma-separated list. Use the ```/helper``` endpoint to get the list of available categories.  Default = All categories.. [optional]
            primary_id (str): Type of identifier search * Y - Returns headlines of stories that have the search ID(s) as the Primary ID. * N - Returns headlines of stories that mention/refer to the ID(s).. [optional] if omitted the server will use the default value of "N"
            search_text (str): Restricts the search to include only document stories which include the text searched.. [optional]
            form_type (str): Restricts the search to include any form types of EDGAR.. [optional]
            accession (str): A unique identifier given to each EDGAR filings document. e.g. accession=0001013237-21-000069&sources=EDG. [optional]
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True. NOTE: if this API returns a file, it is the responsibility
                of the caller to close the file stream.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
        Returns:
            InvestmentResearch
                Response Object
            int
                Http Status Code
            dict
                Dictionary of the response headers
        """
        self.apply_kwargs_defaults(kwargs=kwargs, return_http_data_only=False, async_req=False)
        kwargs['sources'] = \
            sources
        return self.get_filings_endpoint.call_with_http_info(**kwargs)

    def get_filings_async(
        self,
        sources,
        **kwargs
    ) -> "ApplyResult[InvestmentResearch]":
        """Returns the filings documents and related metadata within FactSet coverage.  # noqa: E501

        Returns the filings documents within FactSet coverage along with other response fields  # noqa: E501
        This method makes a asynchronous HTTP request. Returns the http data, wrapped in ApplyResult

        Args:
            sources ([str]): Code for document source to include.  This is a comma-separated list. Use the ```/helper``` endpoint to get the list of available sources.

        Keyword Args:
            ids ([str]): Requested symbols or securities.  This is a comma-separated list with a maximum limit of 1000.  Each symbol can be a FactSet exchange symbol, CUSIP, or SEDOL.. [optional]
            start_date (str): Start Date. Format is YYYYMMDD or relative +/- days (0,-1,etc).. [optional] if omitted the server will use the default value of "0"
            end_date (str): End Date. Format is YYYYMMDD or relative +/- days (0,-1,etc).. [optional] if omitted the server will use the default value of "0"
            pagination_limit (int): Number of results to return per page.. [optional] if omitted the server will use the default value of 25
            pagination_offset (int): Page number of the results to return.. [optional]
            timezone (str): Time zone to return story dates and times. Time zones are in POSIX format and automatically adjusted for daylight savings.. [optional] if omitted the server will use the default value of "America/New_York"
            sort (str): Sorting the results in chronological (oldest to newest) or reverse chronological (newest to oldest) order.    *  desc - sorting results in reverse chronological (descending) order. This is the default value if     the sort parameter isn’t used in the query       *   asc - sorting results in chronological (ascending) order. If a start date is not specified, the    API has a 10-year searching limitation. . [optional] if omitted the server will use the default value of "desc"
            categories ([str]): Code for categories to include.  This is a comma-separated list. Use the ```/helper``` endpoint to get the list of available categories.  Default = All categories.. [optional]
            primary_id (str): Type of identifier search * Y - Returns headlines of stories that have the search ID(s) as the Primary ID. * N - Returns headlines of stories that mention/refer to the ID(s).. [optional] if omitted the server will use the default value of "N"
            search_text (str): Restricts the search to include only document stories which include the text searched.. [optional]
            form_type (str): Restricts the search to include any form types of EDGAR.. [optional]
            accession (str): A unique identifier given to each EDGAR filings document. e.g. accession=0001013237-21-000069&sources=EDG. [optional]
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True. NOTE: if this API returns a file, it is the responsibility
                of the caller to close the file stream.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
        Returns:
            ApplyResult[InvestmentResearch]
        """
        self.apply_kwargs_defaults(kwargs=kwargs, return_http_data_only=True, async_req=True)
        kwargs['sources'] = \
            sources
        return self.get_filings_endpoint.call_with_http_info(**kwargs)

    def get_filings_with_http_info_async(
        self,
        sources,
        **kwargs
    ) -> "ApplyResult[typing.Tuple[InvestmentResearch, int, typing.MutableMapping]]":
        """Returns the filings documents and related metadata within FactSet coverage.  # noqa: E501

        Returns the filings documents within FactSet coverage along with other response fields  # noqa: E501
        This method makes a asynchronous HTTP request. Returns http data, http status and headers, wrapped in ApplyResult

        Args:
            sources ([str]): Code for document source to include.  This is a comma-separated list. Use the ```/helper``` endpoint to get the list of available sources.

        Keyword Args:
            ids ([str]): Requested symbols or securities.  This is a comma-separated list with a maximum limit of 1000.  Each symbol can be a FactSet exchange symbol, CUSIP, or SEDOL.. [optional]
            start_date (str): Start Date. Format is YYYYMMDD or relative +/- days (0,-1,etc).. [optional] if omitted the server will use the default value of "0"
            end_date (str): End Date. Format is YYYYMMDD or relative +/- days (0,-1,etc).. [optional] if omitted the server will use the default value of "0"
            pagination_limit (int): Number of results to return per page.. [optional] if omitted the server will use the default value of 25
            pagination_offset (int): Page number of the results to return.. [optional]
            timezone (str): Time zone to return story dates and times. Time zones are in POSIX format and automatically adjusted for daylight savings.. [optional] if omitted the server will use the default value of "America/New_York"
            sort (str): Sorting the results in chronological (oldest to newest) or reverse chronological (newest to oldest) order.    *  desc - sorting results in reverse chronological (descending) order. This is the default value if     the sort parameter isn’t used in the query       *   asc - sorting results in chronological (ascending) order. If a start date is not specified, the    API has a 10-year searching limitation. . [optional] if omitted the server will use the default value of "desc"
            categories ([str]): Code for categories to include.  This is a comma-separated list. Use the ```/helper``` endpoint to get the list of available categories.  Default = All categories.. [optional]
            primary_id (str): Type of identifier search * Y - Returns headlines of stories that have the search ID(s) as the Primary ID. * N - Returns headlines of stories that mention/refer to the ID(s).. [optional] if omitted the server will use the default value of "N"
            search_text (str): Restricts the search to include only document stories which include the text searched.. [optional]
            form_type (str): Restricts the search to include any form types of EDGAR.. [optional]
            accession (str): A unique identifier given to each EDGAR filings document. e.g. accession=0001013237-21-000069&sources=EDG. [optional]
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True. NOTE: if this API returns a file, it is the responsibility
                of the caller to close the file stream.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
        Returns:
            ApplyResult[(InvestmentResearch, int, typing.Dict)]
        """
        self.apply_kwargs_defaults(kwargs=kwargs, return_http_data_only=False, async_req=True)
        kwargs['sources'] = \
            sources
        return self.get_filings_endpoint.call_with_http_info(**kwargs)


    def get_helper(
        self,
        **kwargs
    ) -> ResponseHelper:
        """Returns the static values for various parameters  # noqa: E501

        Returns the static values for sources,formTypes,timeZones,categories based on the specified parameter  # noqa: E501
        This method makes a synchronous HTTP request. Returns the http data only


        Keyword Args:
            fields (str): Request data for given field.. [optional]
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True. NOTE: if this API returns a file, it is the responsibility
                of the caller to close the file stream.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
        Returns:
            ResponseHelper
                Response Object
        """
        self.apply_kwargs_defaults(kwargs=kwargs, return_http_data_only=True, async_req=False)
        return self.get_helper_endpoint.call_with_http_info(**kwargs)

    def get_helper_with_http_info(
        self,
        **kwargs
    ) -> typing.Tuple[ResponseHelper, int, typing.MutableMapping]:
        """Returns the static values for various parameters  # noqa: E501

        Returns the static values for sources,formTypes,timeZones,categories based on the specified parameter  # noqa: E501
        This method makes a synchronous HTTP request. Returns http data, http status and headers


        Keyword Args:
            fields (str): Request data for given field.. [optional]
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True. NOTE: if this API returns a file, it is the responsibility
                of the caller to close the file stream.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
        Returns:
            ResponseHelper
                Response Object
            int
                Http Status Code
            dict
                Dictionary of the response headers
        """
        self.apply_kwargs_defaults(kwargs=kwargs, return_http_data_only=False, async_req=False)
        return self.get_helper_endpoint.call_with_http_info(**kwargs)

    def get_helper_async(
        self,
        **kwargs
    ) -> "ApplyResult[ResponseHelper]":
        """Returns the static values for various parameters  # noqa: E501

        Returns the static values for sources,formTypes,timeZones,categories based on the specified parameter  # noqa: E501
        This method makes a asynchronous HTTP request. Returns the http data, wrapped in ApplyResult


        Keyword Args:
            fields (str): Request data for given field.. [optional]
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True. NOTE: if this API returns a file, it is the responsibility
                of the caller to close the file stream.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
        Returns:
            ApplyResult[ResponseHelper]
        """
        self.apply_kwargs_defaults(kwargs=kwargs, return_http_data_only=True, async_req=True)
        return self.get_helper_endpoint.call_with_http_info(**kwargs)

    def get_helper_with_http_info_async(
        self,
        **kwargs
    ) -> "ApplyResult[typing.Tuple[ResponseHelper, int, typing.MutableMapping]]":
        """Returns the static values for various parameters  # noqa: E501

        Returns the static values for sources,formTypes,timeZones,categories based on the specified parameter  # noqa: E501
        This method makes a asynchronous HTTP request. Returns http data, http status and headers, wrapped in ApplyResult


        Keyword Args:
            fields (str): Request data for given field.. [optional]
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True. NOTE: if this API returns a file, it is the responsibility
                of the caller to close the file stream.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
        Returns:
            ApplyResult[(ResponseHelper, int, typing.Dict)]
        """
        self.apply_kwargs_defaults(kwargs=kwargs, return_http_data_only=False, async_req=True)
        return self.get_helper_endpoint.call_with_http_info(**kwargs)


